@@ -73,6 +73,9 @@ class API:
     cached_dataframe = Importable("easier.utils", "cached_dataframe")
     cached_property = Importable("easier.utils", "cached_property")
     cc = Importable("easier.plotting", "ColorCyle", instantiate=True)
+    classifier_evaluation_plots = Importable(
+        "easier.fit_lib", "classifier_evaluation_plots"
+    )
     column_level_flattener = Importable(
         "easier.dataframe_tools", "column_level_flattener"
     )
@@ -123,7 +126,10 @@ class API:
     python_type = Importable("easier.utils", "python_type")
     screen_width_full = Importable("easier.utils", "screen_width_full")
     slugify = Importable("easier.dataframe_tools", "slugify")
+    StreamPlotter = Importable("easier.stream_plotter", "StreamPlotter")
     tqdm_flex = Importable("easier.utils", "tqdm_flex")
+    Tracker = Importable("easier.tracker", "Tracker")
     tvd = Importable("easier.filtering.tvd", "tvd")
+    VonMisesFitter = Importable("easier.vonmises", "VonMisesFitter")
     warnings_mute = Importable("easier.utils", "mute_warnings")
     weekday_string = Importable("easier.dataframe_tools", "weekday_string")
