@@ -7,6 +7,7 @@ import warnings
 @contextlib.contextmanager
 def duck_connection(duck_file_name):
     import duckdb
+
     con = duckdb.connect(duck_file_name, read_only=False)
     try:
         yield con
@@ -20,16 +21,15 @@ class Table:
 
     @property
     def table_name(self):
-        return re.sub(r'^df_*', '', self.name)
+        return re.sub(r"^df_*", "", self.name)
 
     def __get__(self, obj, cls):
         if cls is None:  # pragma: no cover
             return
 
-        return obj.query(f'SELECT * FROM {self.table_name}')
+        return obj.query(f"SELECT * FROM {self.table_name}")
 
     def __set__(self, obj, df=None):
-
         if df is None:
             return
 
@@ -38,10 +38,10 @@ class Table:
 
         with duck_connection(obj.file_name) as con:
             if self.table_name in obj.table_names:
-                con.execute(f'DROP TABLE IF EXISTS {self.table_name}')
+                con.execute(f"DROP TABLE IF EXISTS {self.table_name}")
 
-            con.register('df_in', df)
-            con.execute(f'CREATE TABLE {self.table_name} AS SELECT * FROM df_in')
+            con.register("df_in", df)
+            con.execute(f"CREATE TABLE {self.table_name} AS SELECT * FROM df_in")
 
 
 class Duck:
@@ -72,8 +72,10 @@ class Duck:
     """)
     '''
 
-    def __init__(self, file_name='./duck.ddb', overwrite=False, read_only=False):
-        warnings.warn('You are using a deprecated version of Duck.  Use DuckModel instead')
+    def __init__(self, file_name="./duck.ddb", overwrite=False, read_only=False):
+        warnings.warn(
+            "You are using a deprecated version of Duck.  Use DuckModel instead"
+        )
         self.file_name = file_name
         self._read_only = read_only
 
@@ -82,16 +84,19 @@ class Duck:
 
         if os.path.isfile(self.file_name):
             for table in self.table_names:
-                setattr(self, f'df_{table}', None)
+                setattr(self, f"df_{table}", None)
 
     @property
     def table_names(self):
-        df = self.query('PRAGMA show_tables')
+        df = self.query("PRAGMA show_tables")
         return list(df.name)
 
     def __setattr__(self, name, value):
         import pandas as pd
-        if (isinstance(value, pd.DataFrame) or value is None) and name.startswith('df_'):
+
+        if (isinstance(value, pd.DataFrame) or value is None) and name.startswith(
+            "df_"
+        ):
             setattr(self.__class__, name, Table(name))
         super().__setattr__(name, value)
 
@@ -105,22 +110,18 @@ class Duck:
         return df
 
     def export_db(self, directory):
-        #TODO: Duck db hardcodes the export path.  Try to find a way to make this portable
+        # TODO: Duck db hardcodes the export path.  Try to find a way to make this portable
         directory = os.path.realpath(os.path.expanduser(directory))
         if os.path.isfile(directory) or os.path.isdir(directory):
-            raise ValueError(f'\n\n {directory!r} already exists.  Cannot overwrite. Nothing done.')
+            raise ValueError(
+                f"\n\n {directory!r} already exists.  Cannot overwrite. Nothing done."
+            )
 
-        self.query(
-            f'EXPORT DATABASE {directory!r};',
-            fetch=False
-        )
+        self.query(f"EXPORT DATABASE {directory!r};", fetch=False)
 
     def import_db(self, directory):
         directory = os.path.realpath(os.path.expanduser(directory))
         if not os.path.isdir(directory):
-            raise ValueError(f'\n\n {directory!r} Not found.  Nothing done')
+            raise ValueError(f"\n\n {directory!r} Not found.  Nothing done")
 
-        self.query(
-            f'import DATABASE {directory!r};',
-            fetch=False
-        )
+        self.query(f"import DATABASE {directory!r};", fetch=False)
