@@ -1,3 +1,3 @@
-__all__ = ['Elliptic', 'tvd']
+__all__ = ["Elliptic", "tvd"]
 from .elliptic_filter import Elliptic
 from .tvd import tvd
